@@ -6,6 +6,7 @@ from .api.androidclient import AndroidAPIClient
 from .api.defaultclient import DefaultAPIClient
 from .api.webclient import WebAPIClient
 from .exceptions import LoginError
+from .texts import texts
 
 __all__ = ['LoginHandler']
 
@@ -21,68 +22,56 @@ class LoginHandler:
         self.password = password
 
     def web_login(self, username=None, password=None):
-        if username and password:
+        if username is not None:
             self.username = username
+        if password is not None:
             self.password = password
 
         try:
-            util.log('Attempting Web Login ...')
+            util.log(texts.ATTEMPT_WEB_LOGIN)
             return self.LoginStatus.PC, WebAPIClient(self.username, self.password)
         except LoginError as e:
-            util.log(f'web login failed: {e}')
+            util.log(texts.WEB_LOGIN_FAILED.format(e=e))
             return self.LoginStatus.LOG_OUT, DefaultAPIClient()
 
     def android_login(self, username=None, password=None):
-        if username and password:
+        if username is not None:
             self.username = username
+        if password is not None:
             self.password = password
 
         try:
-            util.log('Attempting Android Login ...')
+            util.log(texts.ATTEMPT_ANDROID_LOGIN)
             return self.LoginStatus.ANDROID, AndroidAPIClient(self.username, self.password)
         except LoginError as e:
-            util.log(f'android login failed: {e}')
+            util.log(texts.ANDROID_LOGIN_FAILED.format(e=e))
             return self.LoginStatus.LOG_OUT, DefaultAPIClient()
 
     def login(self, username=None, password=None):
-        if username and password:
+        if username is not None:
             self.username = username
+        if password is not None:
             self.password = password
 
         try:
-            util.log('Attempting Web Login ...')
+            util.log(texts.ATTEMPT_ANDROID_LOGIN)
 
-            client = WebAPIClient(self.username, self.password)
-            login_status = self.LoginStatus.PC
+            client = AndroidAPIClient(self.username, self.password)
+            login_status = self.LoginStatus.ANDROID
 
         except LoginError as e:
-            util.log(f'Web Login failed: {e}')
+            util.log(texts.ANDROID_LOGIN_FAILED.format(e=e))
             try:
-                util.log('Attempting Android Login ...')
+                util.log(texts.ATTEMPT_WEB_LOGIN)
 
-                client = AndroidAPIClient(self.username, self.password)
-                login_status = self.LoginStatus.ANDROID
+                client = WebAPIClient(self.username, self.password)
+                login_status = self.LoginStatus.PC
 
             except LoginError as e:
-                util.log(f'Android Login failed: {e}')
+                util.log(texts.WEB_LOGIN_FAILED.format(e=e))
 
                 client = DefaultAPIClient()
                 login_status = self.LoginStatus.LOG_OUT
 
-        util.log(f'Login Status: {login_status}, API Client: {client}', start=os.linesep, inform=True)
+        util.log(texts.LOGIN_STATUS.format(login_status=login_status, client=client), start=os.linesep, inform=True)
         return login_status, client
-
-
-def main():
-    from . import settings
-    loginer = LoginHandler(settings.username, settings.password)
-    status, client = loginer.web_login()
-    assert status is LoginHandler.LoginStatus.PC
-    status, client = loginer.android_login()
-    assert status is LoginHandler.LoginStatus.ANDROID
-
-    print('Successfully tested login handler')
-
-
-if __name__ == '__main__':
-    main()
